Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(746)

Unified Diff: media/base/pipeline_impl.h

Issue 2718483003: Use base::Optional for selected video track. (Closed)
Patch Set: rebase Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/base/pipeline.h ('k') | media/base/pipeline_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/pipeline_impl.h
diff --git a/media/base/pipeline_impl.h b/media/base/pipeline_impl.h
index b5f5699e9f80bbd86ddf36a3949b829f48f12cdb..54f3c896cbcb75095463d427af14e3d59b4b1a8c 100644
--- a/media/base/pipeline_impl.h
+++ b/media/base/pipeline_impl.h
@@ -95,14 +95,14 @@ class MEDIA_EXPORT PipelineImpl : public Pipeline {
void SetCdm(CdmContext* cdm_context,
const CdmAttachedCB& cdm_attached_cb) override;
// |enabledTrackIds| contains track ids of enabled audio tracks.
void OnEnabledAudioTracksChanged(
- const std::vector<MediaTrack::Id>& enabledTrackIds) override;
+ const std::vector<MediaTrack::Id>& enabled_track_ids) override;
- // |trackId| either empty, which means no video track is selected, or contain
- // one element - the selected video track id.
+ // |selected_track_id| is either empty, which means no video track is
+ // selected, or contains the selected video track id.
void OnSelectedVideoTrackChanged(
- const std::vector<MediaTrack::Id>& selectedTrackId) override;
+ base::Optional<MediaTrack::Id> selected_track_id) override;
private:
friend class MediaLog;
« no previous file with comments | « media/base/pipeline.h ('k') | media/base/pipeline_impl.cc » ('j') | no next file with comments »
@@ -95,14 +95,14 @@ class MEDIA_EXPORT PipelineImpl : public Pipeline {
void SetCdm(CdmContext* cdm_context,
const CdmAttachedCB& cdm_attached_cb) override;
- // |enabledTrackIds| contains track ids of enabled audio tracks.
+ // |enabled_track_ids| contains track ids of enabled audio tracks.
void OnEnabledAudioTracksChanged(

Powered by Google App Engine
This is Rietveld 408576698